(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     61604,       1932]
NotebookOptionsPosition[     58730,       1838]
NotebookOutlinePosition[     59198,       1857]
CellTagsIndexPosition[     59155,       1854]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Simplifications of coil forces", "Section"],

Cell[TextData[{
 "This ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " notebook is an implementation of the expressions presented in the \
publication \"A simplification of the force equation for radially-aligned \
cylindrical magnets\" by Will Robertson, Romain Ravaud, et al., IEEE \
Transactions on Magnetics, 2010."
}], "Text"],

Cell[CellGroupData[{

Cell["Expressions", "Subsection"],

Cell["\<\
Note the first two expressions here  produce the force on the first magnet \
due to the second; in the third equation (and in the paper), we reverse the \
signs to express the force on the second magnet due to the first.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Ravaud's raw Mathematica version", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f5", "[", 
    RowBox[{"rt_", ",", "rtt_", ",", "a_", ",", "b_", ",", "c_", ",", "u_"}], 
    "]"}], "=", 
   RowBox[{"rt", " ", "rtt", " ", 
    RowBox[{"(", 
     RowBox[{
      SqrtBox[
       RowBox[{"1", "-", 
        SuperscriptBox["u", "2"]}]], "-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "-", "b"}], ")"}], " ", 
        RowBox[{"ArcSin", "[", "u", "]"}]}], "c"], "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"c", " ", 
         SqrtBox[
          RowBox[{"1", "-", "u"}]], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{"c", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "u"}], ")"}]}], 
           RowBox[{
            RowBox[{"-", "b"}], "+", "c"}]]], " ", 
         SqrtBox[
          RowBox[{"b", "+", 
           RowBox[{"c", " ", "u"}]}]], " ", 
         SqrtBox[
          RowBox[{"1", "-", 
           SuperscriptBox["u", "2"]}]]}]], 
       RowBox[{"(", 
        RowBox[{"2", " ", "a", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"b", "+", "c"}], ")"}], " ", 
            SqrtBox[
             RowBox[{"1", "-", "u"}]], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "u"}], ")"}], " ", 
            SqrtBox[
             FractionBox[
              RowBox[{"c", "-", 
               RowBox[{"c", " ", "u"}]}], 
              RowBox[{"b", "+", "c"}]]], " ", 
            SqrtBox[
             FractionBox[
              RowBox[{"b", "+", 
               RowBox[{"c", " ", "u"}]}], 
              RowBox[{"b", "-", "c"}]]], " ", 
            RowBox[{"EllipticE", "[", 
             RowBox[{
              RowBox[{"ArcSin", "[", 
               SqrtBox[
                FractionBox[
                 RowBox[{"b", "+", 
                  RowBox[{"c", " ", "u"}]}], 
                 RowBox[{"b", "-", "c"}]]], "]"}], ",", 
              FractionBox[
               RowBox[{"b", "-", "c"}], 
               RowBox[{"b", "+", "c"}]]}], "]"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["a", "2"]}], "+", "b"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "u"}], ")"}], " ", 
            SqrtBox[
             RowBox[{"1", "+", "u"}]], " ", 
            SqrtBox[
             FractionBox[
              RowBox[{"c", " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", "u"}], ")"}]}], 
              RowBox[{
               RowBox[{"-", "b"}], "+", "c"}]]], " ", 
            SqrtBox[
             FractionBox[
              RowBox[{"b", "+", 
               RowBox[{"c", " ", "u"}]}], 
              RowBox[{"b", "+", "c"}]]], " ", 
            RowBox[{"EllipticF", "[", 
             RowBox[{
              RowBox[{"ArcSin", "[", 
               FractionBox[
                SqrtBox[
                 RowBox[{"1", "-", "u"}]], 
                SqrtBox["2"]], "]"}], ",", 
              FractionBox[
               RowBox[{"2", " ", "c"}], 
               RowBox[{"b", "+", "c"}]]}], "]"}]}], "-", 
           RowBox[{
            SqrtBox[
             RowBox[{"1", "-", "u"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"c", " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", "u"}], ")"}], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{"c", "-", 
                  RowBox[{"c", " ", "u"}]}], 
                 RowBox[{"b", "+", "c"}]]], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{"b", "+", 
                  RowBox[{"c", " ", "u"}]}], 
                 RowBox[{"b", "-", "c"}]]], " ", 
               RowBox[{"EllipticF", "[", 
                RowBox[{
                 RowBox[{"ArcSin", "[", 
                  SqrtBox[
                   FractionBox[
                    RowBox[{"b", "+", 
                    RowBox[{"c", " ", "u"}]}], 
                    RowBox[{"b", "-", "c"}]]], "]"}], ",", 
                 FractionBox[
                  RowBox[{"b", "-", "c"}], 
                  RowBox[{"b", "+", "c"}]]}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  SuperscriptBox["a", "2"]}], "+", "b", "-", "c"}], ")"}], 
               " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{"c", " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "u"}], ")"}]}], 
                 RowBox[{
                  RowBox[{"-", "b"}], "+", "c"}]]], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{"b", "+", 
                  RowBox[{"c", " ", "u"}]}], 
                 RowBox[{"b", "+", "c"}]]], " ", 
               SqrtBox[
                RowBox[{"1", "-", 
                 SuperscriptBox["u", "2"]}]], " ", 
               RowBox[{"EllipticPi", "[", 
                RowBox[{
                 FractionBox[
                  RowBox[{"2", " ", "c"}], 
                  RowBox[{
                   RowBox[{"-", 
                    SuperscriptBox["a", "2"]}], "+", "b", "+", "c"}]], ",", 
                 RowBox[{"ArcSin", "[", 
                  FractionBox[
                   SqrtBox[
                    RowBox[{"1", "-", "u"}]], 
                   SqrtBox["2"]], "]"}], ",", 
                 FractionBox[
                  RowBox[{"2", " ", "c"}], 
                  RowBox[{"b", "+", "c"}]]}], "]"}]}]}], ")"}]}]}], ")"}]}], 
        ")"}]}], "-", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"1", "-", 
         SuperscriptBox["u", "2"]}]], " ", 
       RowBox[{"Log", "[", 
        RowBox[{"a", "+", 
         SqrtBox[
          RowBox[{"b", "+", 
           RowBox[{"c", " ", "u"}]}]]}], "]"}]}], "-", 
      FractionBox[
       RowBox[{
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "4"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"], " ", "b"}], "-", 
          SuperscriptBox["b", "2"], "+", 
          SuperscriptBox["c", "2"]}]], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{"4", " ", 
           SuperscriptBox["c", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"c", "-", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", "u"}], "+", 
             RowBox[{"b", " ", "u"}], "+", 
             RowBox[{
              SqrtBox[
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["a", "4"]}], "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["a", "2"], " ", "b"}], "-", 
                SuperscriptBox["b", "2"], "+", 
                SuperscriptBox["c", "2"]}]], " ", 
              SqrtBox[
               RowBox[{"1", "-", 
                SuperscriptBox["u", "2"]}]]}]}], ")"}]}], 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["a", "4"]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["a", "2"], " ", "b"}], "-", 
              SuperscriptBox["b", "2"], "+", 
              SuperscriptBox["c", "2"]}], ")"}], 
            RowBox[{"3", "/", "2"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], "+", "b", "+", 
             RowBox[{"c", " ", "u"}]}], ")"}]}]], "]"}]}], "c"]}], ")"}]}]}], 
  ";", 
  RowBox[{
   RowBox[{"f4", "[", 
    RowBox[{"rt_", ",", "rtt_", ",", "zt_", ",", "ztt_", ",", "u_"}], "]"}], ":=",
    
   RowBox[{"f5", "[", 
    RowBox[{"rt", ",", "rtt", ",", 
     RowBox[{"zt", "-", "ztt"}], ",", 
     RowBox[{
      RowBox[{"rt", "^", "2"}], "+", 
      RowBox[{"rtt", "^", "2"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"zt", "-", "ztt"}], ")"}], "^", "2"}]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], "*", "rt", "*", "rtt"}], ",", "u"}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"f3", "[", 
    RowBox[{"rt_", ",", "rtt_", ",", "zt_", ",", "ztt_"}], "]"}], ":=", 
   RowBox[{"Re", "[", 
    RowBox[{
     RowBox[{"f4", "[", 
      RowBox[{"rt", ",", "rtt", ",", "zt", ",", "ztt", ",", 
       RowBox[{"-", "0.9999999999999999"}]}], "]"}], "-", 
     RowBox[{"f4", "[", 
      RowBox[{
      "rt", ",", "rtt", ",", "zt", ",", "ztt", ",", "0.9999999999999999"}], 
      "]"}]}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"f2", "[", 
    RowBox[{"rt_", ",", "rtt_", ",", "zt_", ",", "z3_", ",", "z4_"}], "]"}], ":=",
    
   RowBox[{
    RowBox[{"f3", "[", 
     RowBox[{"rt", ",", "rtt", ",", "zt", ",", "z4"}], "]"}], "-", 
    RowBox[{"f3", "[", 
     RowBox[{"rt", ",", "rtt", ",", "zt", ",", "z3"}], "]"}]}]}], ";", 
  RowBox[{
   RowBox[{"f1", "[", 
    RowBox[{
    "rt_", ",", "rtt_", ",", "z1_", ",", "z2_", ",", "z3_", ",", "z4_"}], 
    "]"}], ":=", 
   RowBox[{
    RowBox[{"f2", "[", 
     RowBox[{"rt", ",", "rtt", ",", "z2", ",", "z3", ",", "z4"}], "]"}], "-", 
    
    RowBox[{"f2", "[", 
     RowBox[{"rt", ",", "rtt", ",", "z1", ",", "z3", ",", "z4"}], "]"}]}]}], 
  ";", 
  RowBox[{
   RowBox[{"forceaxiale", "[", 
    RowBox[{
    "J1_", ",", "J2_", ",", "r1_", ",", "r2_", ",", "z1_", ",", "z2_", ",", 
     "z3_", ",", "z4_"}], "]"}], ":=", 
   RowBox[{"J1", "*", 
    RowBox[{"J2", "/", 
     RowBox[{"(", 
      RowBox[{"2", "*", "mu0"}], ")"}]}], "*", 
    RowBox[{"f1", "[", 
     RowBox[{"r1", ",", "r2", ",", "z1", ",", "z2", ",", "z3", ",", "z4"}], 
     "]"}]}]}], ";", 
  RowBox[{"mu0", "=", 
   RowBox[{"4", "*", "Pi", "*", 
    RowBox[{"10", "^", 
     RowBox[{"(", 
      RowBox[{"-", "7"}], ")"}]}]}]}], ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{"Timing", "[", 
  RowBox[{"forceaxiale", "[", 
   RowBox[{
   "1", ",", "1", ",", "0.05", ",", "0.05000001", ",", "0.001", ",", "0.002", 
    ",", "0.0052", ",", "0.0055"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Timing", "[", 
  RowBox[{"forceaxiale", "[", 
   RowBox[{
   "1", ",", "1", ",", "0.05", ",", "0.06", ",", "0.001", ",", "0.002", ",", 
    "0.0052", ",", "0.0055"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Timing", "[", 
  RowBox[{"forceaxiale", "[", 
   RowBox[{
   "1", ",", "1", ",", "0.05", ",", "0.04", ",", "0.001", ",", "0.002", ",", 
    "0.0052", ",", "0.0055"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Timing", "[", 
  RowBox[{"forceaxiale", "[", 
   RowBox[{"1", ",", 
    RowBox[{"-", "1"}], ",", "0.05", ",", "0.04", ",", "0.001", ",", "0.002", 
    ",", "0.002", ",", "0.004"}], "]"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"time1", "=", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"NN", "=", "10000"}], "}"}], ",", 
    RowBox[{
     RowBox[{"First", "[", 
      RowBox[{"Timing", "[", 
       RowBox[{"Do", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"forceaxiale", "[", 
          RowBox[{
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.5", ",", "1.5"}], "}"}]}], "]"}], ",", 
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.5", ",", "1.5"}], "}"}]}], "]"}], ",", 
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.002", ",", "0.1"}], "}"}]}], "]"}], ",", 
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.002", ",", "0.1"}], "}"}]}], "]"}], ",", 
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.002", ",", "0.1"}], "}"}]}], "]"}], ",", 
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.002", ",", "0.1"}], "}"}]}], "]"}], ",", 
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.002", ",", "0.1"}], "}"}]}], "]"}], ",", 
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.002", ",", "0.1"}], "}"}]}], "]"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", "NN", "}"}]}], "]"}], "]"}], "]"}], "/", "NN"}]}], 
   "]"}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Published version", "Subsubsection"],

Cell[TextData[{
 "Now that you have reached this far, I have a confession to make: the \
following equation comes verbatim from Ravaud's paper but it does not \
calculate the same values as his ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " code listed above; I must therefore conclude that there is a typo in his \
paper. Nonetheless, the equation below is used to compare the performance of \
the simplified equation."
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"muo", "=", 
   RowBox[{"4", "*", "Pi", "*", 
    RowBox[{"10", "^", 
     RowBox[{"(", 
      RowBox[{"-", "7"}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"forceaxiale2", "[", 
    RowBox[{
    "J1_", ",", "J2_", ",", "r1_", ",", "r2_", ",", "z1_", ",", "z2_", ",", 
     "z3_", ",", "z4_"}], "]"}], ":=", 
   RowBox[{"J1", "*", 
    RowBox[{"J2", "/", 
     RowBox[{"(", 
      RowBox[{"2", "*", "muo"}], ")"}]}], "*", 
    RowBox[{"ff1", "[", 
     RowBox[{"r1", ",", "r2", ",", "z1", ",", "z2", ",", "z3", ",", "z4"}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ff1", "[", 
    RowBox[{
    "r1_", ",", "r2_", ",", "z1_", ",", "z2_", ",", "z3_", ",", "z4_"}], 
    "]"}], ":=", 
   RowBox[{
    RowBox[{"ff2", "[", 
     RowBox[{"r1", ",", "r2", ",", "z2", ",", "z3", ",", "z4"}], "]"}], "-", 
    RowBox[{"ff2", "[", 
     RowBox[{"r1", ",", "r2", ",", "z1", ",", "z3", ",", "z4"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ff2", "[", 
    RowBox[{"r1_", ",", "r2_", ",", "zt_", ",", "z3_", ",", "z4_"}], "]"}], ":=",
    
   RowBox[{
    RowBox[{"ff3", "[", 
     RowBox[{"r1", ",", "r2", ",", "zt", ",", "z4"}], "]"}], "-", 
    RowBox[{"ff3", "[", 
     RowBox[{"r1", ",", "r2", ",", "zt", ",", "z3"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ff3", "[", 
    RowBox[{"r1_", ",", "r2_", ",", "zt_", ",", "ztt_"}], "]"}], ":=", " ", 
   RowBox[{"Re", "[", 
    RowBox[{"ff4", "[", 
     RowBox[{"zt", ",", "ztt", ",", "r1", ",", "r2"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ff4", "[", 
   RowBox[{"zt_", ",", "ztt_", ",", "r1_", ",", "r2_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "\[Omega]", ",", "\[Tau]", ",", "\[Epsilon]", ",", "\[Iota]", ",", 
      "\[Beta]", ",", "\[Kappa]", ",", "\[Gamma]", ",", "\[Delta]", ",", 
      "\[Psi]", ",", "\[Nu]"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Omega]", "=", 
      RowBox[{"zt", "-", "ztt"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Tau]", "=", 
      RowBox[{
       SuperscriptBox["r1", "2"], "+", 
       SuperscriptBox["r2", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"zt", "-", "ztt"}], ")"}], "2"]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"\[Epsilon]", "=", 
      RowBox[{
       RowBox[{"-", "2"}], "r1", " ", "r2"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Nu]", "=", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[Omega]", "4"]}], "+", 
       RowBox[{"2", 
        SuperscriptBox["\[Omega]", "2"], "\[Tau]"}], "-", 
       SuperscriptBox["\[Tau]", "2"], "+", 
       SuperscriptBox["\[Epsilon]", "2"]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Iota]", "=", 
      FractionBox["\[Epsilon]", 
       RowBox[{"\[Tau]", "+", "\[Epsilon]"}]]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Beta]", "=", 
      FractionBox["\[Epsilon]", 
       RowBox[{"\[Tau]", "-", "\[Epsilon]"}]]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Kappa]", "=", 
      RowBox[{"\[Epsilon]", 
       SqrtBox[
        RowBox[{"\[Tau]", "-", "\[Epsilon]"}]]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"\[Gamma]", "=", 
      RowBox[{
       SuperscriptBox["\[Omega]", "2"], "-", "\[Tau]", "+", "\[Epsilon]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"\[Delta]", "=", 
      FractionBox["\[Epsilon]", 
       RowBox[{"\[Tau]", "+", "\[Epsilon]", "-", 
        SuperscriptBox["\[Omega]", "2"]}]]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Psi]", "=", 
      FractionBox[
       RowBox[{"\[Tau]", "-", "\[Epsilon]"}], 
       RowBox[{"\[Tau]", "+", "\[Epsilon]"}]]}], ";", "\[IndentingNewLine]", 
     RowBox[{"r1", " ", "r2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Az", "[", 
         RowBox[{"\[Omega]", ",", "\[Tau]", ",", "\[Nu]", ",", "\[Epsilon]"}],
          "]"}], "+", 
        RowBox[{"ff5", "[", 
         RowBox[{
         "\[Omega]", ",", "\[Tau]", ",", "\[Epsilon]", ",", "\[Iota]", ",", 
          "\[Beta]", ",", "\[Kappa]", ",", "\[Gamma]", ",", "\[Delta]", ",", 
          "\[Psi]"}], "]"}]}], ")"}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Az", "[", 
   RowBox[{"\[Omega]_", ",", "\[Tau]_", ",", "\[Nu]_", ",", "\[Epsilon]_"}], 
   "]"}], ":=", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["\[Omega]", "2"], "-", "\[Tau]"}], ")"}], "\[Pi]"}], 
      "-", 
      RowBox[{"2", 
       SqrtBox["\[Nu]"]}]}], 
     RowBox[{"2", "\[Epsilon]"}]], 
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "4"}], 
       SuperscriptBox["\[Epsilon]", "2"]}], 
      SuperscriptBox["\[Nu]", 
       RowBox[{"3", "/", "2"}]]], "]"}]}], "-", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["\[Omega]", "2"]}], "+", "\[Tau]"}], ")"}], 
       "\[Pi]"}], "-", 
      RowBox[{"2", 
       SqrtBox["\[Nu]"]}]}], 
     RowBox[{"2", "\[Epsilon]"}]], 
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"4", 
       SuperscriptBox["\[Epsilon]", "2"]}], 
      SuperscriptBox["\[Nu]", 
       RowBox[{"3", "/", "2"}]]], "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ff5", "[", 
    RowBox[{
    "\[Omega]_", ",", "\[Tau]_", ",", "\[Epsilon]_", ",", "\[Iota]_", ",", 
     "\[Beta]_", ",", "\[Kappa]_", ",", "\[Gamma]_", ",", "\[Delta]_", ",", 
     "\[Psi]_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"2", "\[ImaginaryI]", " ", "\[Omega]"}], 
      RowBox[{"\[Epsilon]", 
       SqrtBox[
        RowBox[{"\[Tau]", "+", "\[Epsilon]"}]]}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Tau]", "+", "\[Epsilon]"}], ")"}], 
        RowBox[{"EllipticE", "[", 
         RowBox[{
          RowBox[{"ArcSin", "[", 
           SqrtBox[
            FractionBox["1", "\[Psi]"]], "]"}], ",", "\[Psi]"}], "]"}]}], "-",
        
       RowBox[{"\[Epsilon]", " ", 
        RowBox[{"EllipticF", "[", 
         RowBox[{
          RowBox[{"ArcSin", "[", 
           SqrtBox[
            FractionBox["1", "\[Psi]"]], "]"}], ",", "\[Psi]"}], "]"}]}]}], 
      ")"}]}], "+", 
    RowBox[{
     FractionBox[
      RowBox[{"2", "\[Omega]"}], 
      RowBox[{"\[Kappa]", 
       SqrtBox["\[Beta]"]}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["\[Epsilon]", "\[Iota]"], 
        RowBox[{"EllipticE", "[", "\[Psi]", "]"}]}], "-", 
       RowBox[{"\[Epsilon]", 
        SqrtBox["\[Iota]"], 
        RowBox[{"EllipticK", "[", "\[Psi]", "]"}]}], "+", 
       RowBox[{
        SqrtBox[
         RowBox[{"\[Beta]", " ", "\[Psi]"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"\[Tau]", "-", 
             SuperscriptBox["\[Omega]", "2"]}], ")"}], 
           RowBox[{"EllipticK", "[", 
            RowBox[{"2", "\[Iota]"}], "]"}]}], "+", 
          RowBox[{"\[Gamma]", " ", 
           RowBox[{"EllipticPi", "[", 
            RowBox[{
             RowBox[{"2", "\[Delta]"}], ",", 
             RowBox[{"2", "\[Iota]"}]}], "]"}]}]}], ")"}]}]}], ")"}]}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Timing", "[", 
  RowBox[{"forceaxiale2", "[", 
   RowBox[{
   "1", ",", "1", ",", "0.05", ",", "0.05000001", ",", "0.001", ",", "0.002", 
    ",", "0.0052", ",", "0.0055"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Timing", "[", 
  RowBox[{"forceaxiale2", "[", 
   RowBox[{
   "1", ",", "1", ",", "0.05", ",", "0.06", ",", "0.001", ",", "0.002", ",", 
    "0.0052", ",", "0.0055"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Timing", "[", 
  RowBox[{"forceaxiale2", "[", 
   RowBox[{"1", ",", 
    RowBox[{"-", "1"}], ",", "0.05", ",", "0.04", ",", "0.001", ",", "0.002", 
    ",", "0.0052", ",", "0.0055"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Timing", "[", 
  RowBox[{"forceaxiale2", "[", 
   RowBox[{"1", ",", 
    RowBox[{"-", "1"}], ",", "0.05", ",", "0.04", ",", "0.001", ",", "0.002", 
    ",", "0.002", ",", "0.004"}], "]"}], "]"}]}], "Input",
 FontSize->14],

Cell[BoxData[
 RowBox[{"time2", "=", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"NN", "=", "10000"}], "}"}], ",", 
    RowBox[{
     RowBox[{"First", "[", 
      RowBox[{"Timing", "[", 
       RowBox[{"Do", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"forceaxiale2", "[", 
          RowBox[{
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.5", ",", "1.5"}], "}"}]}], "]"}], ",", 
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.5", ",", "1.5"}], "}"}]}], "]"}], ",", 
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.002", ",", "0.1"}], "}"}]}], "]"}], ",", 
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.002", ",", "0.1"}], "}"}]}], "]"}], ",", 
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.002", ",", "0.1"}], "}"}]}], "]"}], ",", 
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.002", ",", "0.1"}], "}"}]}], "]"}], ",", 
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.002", ",", "0.1"}], "}"}]}], "]"}], ",", 
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.002", ",", "0.1"}], "}"}]}], "]"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", "NN", "}"}]}], "]"}], "]"}], "]"}], "/", "NN"}]}], 
   "]"}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Simplified version (minimal parameters)", "Subsubsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["\[Mu]", "0"], "=", 
   RowBox[{"4", "\[Pi]", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "7"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"newforce", "[", 
   RowBox[{
   "J1_", ",", "J2_", ",", "r1_", ",", "r2_", ",", "z1_", ",", "z2_", ",", 
    "z3_", ",", "z4_"}], "]"}], ":=", 
  RowBox[{
   FractionBox[
    RowBox[{"J1", " ", "J2"}], 
    RowBox[{"2", 
     SubscriptBox["\[Mu]", "0"]}]], 
   RowBox[{"fs1", "[", 
    RowBox[{"r1", ",", "r2", ",", "z1", ",", "z2", ",", "z3", ",", "z4"}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fs1", "[", 
   RowBox[{
   "r1_", ",", "r2_", ",", "z1_", ",", "z2_", ",", "z3_", ",", "z4_"}], "]"}],
   ":=", 
  RowBox[{
   RowBox[{"fs2", "[", 
    RowBox[{"r1", ",", "r2", ",", "z2", ",", "z3", ",", "z4"}], "]"}], "-", 
   RowBox[{"fs2", "[", 
    RowBox[{"r1", ",", "r2", ",", "z1", ",", "z3", ",", "z4"}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fs2", "[", 
   RowBox[{"r1_", ",", "r2_", ",", "zt_", ",", "z3_", ",", "z4_"}], "]"}], ":=",
   
  RowBox[{
   RowBox[{"fs3", "[", 
    RowBox[{"r1", ",", "r2", ",", "zt", ",", "z4"}], "]"}], "-", 
   RowBox[{"fs3", "[", 
    RowBox[{"r1", ",", "r2", ",", "zt", ",", "z3"}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fs3", "[", 
   RowBox[{"r1_", ",", "r2_", ",", "zt_", ",", "ztt_"}], "]"}], ":=", " ", 
  "\[IndentingNewLine]", 
  RowBox[{"fs4", "[", 
   RowBox[{
    RowBox[{"zt", "-", "ztt"}], ",", 
    RowBox[{"r1", "-", "r2"}], ",", 
    RowBox[{"r1", "+", "r2"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fs4", "[", 
    RowBox[{"c1_", ",", "c2_", ",", "c3_"}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"c1", "\[Equal]", "0"}], ",", "0", ",", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "c1"}], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["c1", "2"], "+", 
         SuperscriptBox["c3", "2"]}]], " ", 
       RowBox[{"EllipticE", "[", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["c2", "2"]}], "+", 
          SuperscriptBox["c3", "2"]}], 
         RowBox[{
          SuperscriptBox["c1", "2"], "+", 
          SuperscriptBox["c3", "2"]}]], "]"}]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["c1", "2"], "+", 
          SuperscriptBox["c2", "2"]}], ")"}], " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["c1", "2"], "+", 
          SuperscriptBox["c3", "2"]}]], " ", 
        RowBox[{"EllipticK", "[", 
         FractionBox[
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["c2", "2"]}], "+", 
           SuperscriptBox["c3", "2"]}], 
          RowBox[{
           SuperscriptBox["c1", "2"], "+", 
           SuperscriptBox["c3", "2"]}]], "]"}]}], "c1"], "-", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"c2", "\[Equal]", "0"}], ",", "0", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["c1", "2"], "+", 
            SuperscriptBox["c2", "2"]}], ")"}], " ", 
          SuperscriptBox["c3", "2"], " ", 
          RowBox[{"EllipticPi", "[", 
           RowBox[{
            FractionBox[
             RowBox[{
              SuperscriptBox["c1", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["c2", "2"], "-", 
                SuperscriptBox["c3", "2"]}], ")"}]}], 
             RowBox[{
              SuperscriptBox["c2", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["c1", "2"], "+", 
                SuperscriptBox["c3", "2"]}], ")"}]}]], ",", 
            FractionBox[
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["c2", "2"]}], "+", 
              SuperscriptBox["c3", "2"]}], 
             RowBox[{
              SuperscriptBox["c1", "2"], "+", 
              SuperscriptBox["c3", "2"]}]]}], "]"}]}], 
         RowBox[{"c1", " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["c1", "2"], "+", 
            SuperscriptBox["c3", "2"]}]]}]]}], "]"}]}]}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Timing", "[", 
  RowBox[{"newforce", "[", 
   RowBox[{"1", ",", 
    RowBox[{"-", "1"}], ",", "0.05", ",", "0.05", ",", "0.001", ",", "0.002", 
    ",", "0.0052", ",", "0.0055"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Timing", "[", 
  RowBox[{"newforce", "[", 
   RowBox[{"1", ",", 
    RowBox[{"-", "1"}], ",", "0.05", ",", "0.06", ",", "0.001", ",", "0.002", 
    ",", "0.0052", ",", "0.0055"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Timing", "[", 
  RowBox[{"newforce", "[", 
   RowBox[{"1", ",", 
    RowBox[{"-", "1"}], ",", "0.05", ",", "0.04", ",", "0.001", ",", "0.002", 
    ",", "0.0052", ",", "0.0055"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Timing", "[", 
  RowBox[{"newforce", "[", 
   RowBox[{"1", ",", 
    RowBox[{"-", "1"}], ",", "0.05", ",", "0.04", ",", "0.001", ",", "0.002", 
    ",", "0.002", ",", "0.004"}], "]"}], "]"}]}], "Input",
 FontSize->14],

Cell[BoxData[
 RowBox[{"time3", "=", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"NN", "=", "10000"}], "}"}], ",", 
    RowBox[{
     RowBox[{"First", "[", 
      RowBox[{"Timing", "[", 
       RowBox[{"Do", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"newforce", "[", 
          RowBox[{
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.5", ",", "1.5"}], "}"}]}], "]"}], ",", 
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.5", ",", "1.5"}], "}"}]}], "]"}], ",", 
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.002", ",", "0.1"}], "}"}]}], "]"}], ",", 
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.002", ",", "0.1"}], "}"}]}], "]"}], ",", 
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.002", ",", "0.1"}], "}"}]}], "]"}], ",", 
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.002", ",", "0.1"}], "}"}]}], "]"}], ",", 
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.002", ",", "0.1"}], "}"}]}], "]"}], ",", 
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.002", ",", "0.1"}], "}"}]}], "]"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", "NN", "}"}]}], "]"}], "]"}], "]"}], "/", "NN"}]}], 
   "]"}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Simplified version", "Subsubsection"],

Cell[TextData[{
 "This is implemented as a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " package in the file \"MagnetCode.m\" in the same GitHub repository."
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"newforce2", "[", 
   RowBox[{
   "J1_", ",", "J2_", ",", "r1_", ",", "r2_", ",", "z1_", ",", "z2_", ",", 
    "z3_", ",", "z4_"}], "]"}], ":=", 
  RowBox[{
   FractionBox[
    RowBox[{"J1", " ", "J2"}], 
    RowBox[{"8", "\[Pi]", " ", 
     SuperscriptBox["10", 
      RowBox[{"-", "7"}]]}]], 
   RowBox[{"fff1", "[", 
    RowBox[{"r1", ",", "r2", ",", "z1", ",", "z2", ",", "z3", ",", "z4"}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fff1", "[", 
   RowBox[{
   "r1_", ",", "r2_", ",", "z1_", ",", "z2_", ",", "z3_", ",", "z4_"}], "]"}],
   ":=", 
  RowBox[{
   RowBox[{"fff2", "[", 
    RowBox[{"r1", ",", "r2", ",", "z2", ",", "z3", ",", "z4"}], "]"}], "-", 
   RowBox[{"fff2", "[", 
    RowBox[{"r1", ",", "r2", ",", "z1", ",", "z3", ",", "z4"}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fff2", "[", 
   RowBox[{"r1_", ",", "r2_", ",", "zt_", ",", "z3_", ",", "z4_"}], "]"}], ":=",
   
  RowBox[{
   RowBox[{"fff3", "[", 
    RowBox[{"r1", ",", "r2", ",", 
     RowBox[{"zt", "-", "z4"}]}], "]"}], "-", 
   RowBox[{"fff3", "[", 
    RowBox[{"r1", ",", "r2", ",", 
     RowBox[{"zt", "-", "z3"}]}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fff3", "[", 
   RowBox[{"r1_", ",", "r2_", ",", "z_"}], "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"z", "\[Equal]", "0"}], ",", "0", ",", 
    RowBox[{"fff4", "[", 
     RowBox[{"z", ",", 
      RowBox[{
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"r1", "-", "r2"}], ")"}], "2"], 
        SuperscriptBox["z", "2"]], "+", "1"}], ",", 
      SqrtBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"r1", "+", "r2"}], ")"}], "2"], "+", 
        SuperscriptBox["z", "2"]}]], ",", 
      FractionBox[
       RowBox[{"4", " ", "r1", " ", "r2"}], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"r1", "+", "r2"}], ")"}], "2"], "+", 
        SuperscriptBox["z", "2"]}]]}], "]"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fff4", "[", 
   RowBox[{"m1_", ",", "m2_", ",", "m3_", ",", "m4_"}], "]"}], ":=", 
  RowBox[{"m1", " ", "m3", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"m2", " ", 
      RowBox[{"EllipticK", "[", "m4", "]"}]}], "-", 
     RowBox[{"EllipticE", "[", "m4", "]"}], "+", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"m2", "\[Equal]", "1"}], ",", "0", ",", 
       RowBox[{"m2", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            FractionBox[
             RowBox[{"m1", " "}], "m3"], ")"}], "2"], "-", "1"}], ")"}], " ", 
        
        RowBox[{"EllipticPi", "[", 
         RowBox[{
          FractionBox["m4", 
           RowBox[{"1", "-", "m2"}]], ",", "m4"}], "]"}]}]}], "]"}]}], 
    ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Timing", "[", 
  RowBox[{"newforce2", "[", 
   RowBox[{"1", ",", 
    RowBox[{"-", "1"}], ",", "0.05", ",", "0.05", ",", "0.001", ",", "0.002", 
    ",", "0.0052", ",", "0.0055"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Timing", "[", 
  RowBox[{"newforce2", "[", 
   RowBox[{"1", ",", 
    RowBox[{"-", "1"}], ",", "0.05", ",", "0.06", ",", "0.001", ",", "0.002", 
    ",", "0.0052", ",", "0.0055"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Timing", "[", 
  RowBox[{"newforce2", "[", 
   RowBox[{"1", ",", 
    RowBox[{"-", "1"}], ",", "0.05", ",", "0.04", ",", "0.001", ",", "0.002", 
    ",", "0.0052", ",", "0.0055"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Timing", "[", 
  RowBox[{"newforce2", "[", 
   RowBox[{"1", ",", 
    RowBox[{"-", "1"}], ",", "0.05", ",", "0.04", ",", "0.001", ",", "0.002", 
    ",", "0.002", ",", "0.004"}], "]"}], "]"}]}], "Input",
 FontSize->14],

Cell[BoxData[
 RowBox[{"time4", "=", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"NN", "=", "10000"}], "}"}], ",", 
    RowBox[{
     RowBox[{"First", "[", 
      RowBox[{"Timing", "[", 
       RowBox[{"Do", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"newforce2", "[", 
          RowBox[{
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.5", ",", "1.5"}], "}"}]}], "]"}], ",", 
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.5", ",", "1.5"}], "}"}]}], "]"}], ",", 
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.002", ",", "0.1"}], "}"}]}], "]"}], ",", 
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.002", ",", "0.1"}], "}"}]}], "]"}], ",", 
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.002", ",", "0.1"}], "}"}]}], "]"}], ",", 
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.002", ",", "0.1"}], "}"}]}], "]"}], ",", 
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.002", ",", "0.1"}], "}"}]}], "]"}], ",", 
           RowBox[{"Random", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{"0.002", ",", "0.1"}], "}"}]}], "]"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", "NN", "}"}]}], "]"}], "]"}], "]"}], "/", "NN"}]}], 
   "]"}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["TIming comparison", "Subsubsection"],

Cell[BoxData[{
 RowBox[{"1000", "time1"}], "\[IndentingNewLine]", 
 RowBox[{"1000", "time2"}], "\[IndentingNewLine]", 
 RowBox[{"1000", "time3"}], "\[IndentingNewLine]", 
 RowBox[{"1000", "time4"}]}], "Input"],

Cell[BoxData[{
 RowBox[{"time1", "/", "time4"}], "\[IndentingNewLine]", 
 RowBox[{"time2", "/", "time4"}], "\[IndentingNewLine]", 
 RowBox[{"time3", "/", "time4"}]}], "Input"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example", "Section"],

Cell[BoxData[{
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"turns", "=", "100"}], ",", 
     RowBox[{"current", "=", "1"}], ",", 
     RowBox[{"J2", "=", "1"}], ",", 
     RowBox[{"r1", "=", "0.02"}], ",", 
     RowBox[{"r2", "=", "0.015"}], ",", 
     RowBox[{"h1", "=", "0.02"}], ",", 
     RowBox[{"h2", "=", "0.015"}], ",", 
     RowBox[{"displ", "=", "0.045"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fcyl", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", 
          RowBox[{"forceaxiale", "[", 
           RowBox[{
            RowBox[{"mu0", "\[Times]", " ", "turns", "\[Times]", 
             RowBox[{"current", "/", "h1"}]}], ",", "J2", ",", "r1", ",", 
            "r2", ",", 
            RowBox[{
             RowBox[{"-", "h1"}], "/", "2"}], ",", 
            RowBox[{"h1", "/", "2"}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "h2"}], "/", "2"}], "+", 
             RowBox[{"x", "/", "1000"}]}], ",", 
            RowBox[{
             RowBox[{"h2", "/", "2"}], "+", 
             RowBox[{"x", "/", "1000"}]}]}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{
          RowBox[{"-", "1000"}], "displ"}], ",", 
         RowBox[{"1000", "displ"}]}], "}"}]}], "]"}]}], ";"}]}], 
  "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"turns", "=", "100"}], ",", 
     RowBox[{"current", "=", "1"}], ",", 
     RowBox[{"J2", "=", "1"}], ",", 
     RowBox[{"r1", "=", "0.02"}], ",", 
     RowBox[{"r2", "=", "0.015"}], ",", 
     RowBox[{"h1", "=", "0.02"}], ",", 
     RowBox[{"h2", "=", "0.015"}], ",", 
     RowBox[{"displ", "=", "0.045"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fcyl2", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"newforce2", "[", 
          RowBox[{
           RowBox[{"mu0", "\[Times]", " ", "turns", "\[Times]", 
            RowBox[{"current", "/", "h1"}]}], ",", "J2", ",", "r1", ",", "r2",
            ",", 
           RowBox[{
            RowBox[{"-", "h1"}], "/", "2"}], ",", 
           RowBox[{"h1", "/", "2"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "h2"}], "/", "2"}], "+", 
            RowBox[{"x", "/", "1000"}]}], ",", 
           RowBox[{
            RowBox[{"h2", "/", "2"}], "+", 
            RowBox[{"x", "/", "1000"}]}]}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{
          RowBox[{"-", "1000"}], "displ"}], ",", 
         RowBox[{"1000", "displ"}]}], "}"}]}], "]"}]}], ";"}]}], 
  "\[IndentingNewLine]", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"GraphicsRow", "@", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ListPlot", "[", 
     RowBox[{"fcyl", ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Displacement, mm\>\"", ",", "\"\<Force, N\>\"", ",", 
         "\"\<Mathematica\>\"", ",", "\"\<\>\""}], "}"}]}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"fcyl2", ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Displacement, mm\>\"", ",", "\"\<Force, N\>\"", ",", 
         "\"\<Mathematica\>\"", ",", "\"\<\>\""}], "}"}]}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]}], "}"}]}]], "Input"],

Cell["Write data to file for plotting:", "Text"],

Cell[BoxData[{
 RowBox[{"SetDirectory", "@", 
  RowBox[{"NotebookDirectory", "[", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"filename", "=", "\"\<data/magcyl-mma.txt\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f", "=", 
   RowBox[{"OpenWrite", "[", "filename", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"WriteString", "[", 
     RowBox[{"f", ",", 
      RowBox[{
       RowBox[{"ToString", "[", 
        RowBox[{"First", "@", "#"}], "]"}], "<>", "\"\< \>\"", "<>", 
       RowBox[{"ToString", "[", 
        RowBox[{"Last", "@", "#"}], "]"}], "<>", "\"\<\n\>\""}]}], "]"}], 
    "&"}], "/@", 
   RowBox[{"(", 
    RowBox[{"fcyl", "//", "Chop"}], ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Close", "[", "filename", "]"}], ";"}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Check equations", "Section"],

Cell[CellGroupData[{

Cell["Reciprocal-modulus for ArcSin terms", "Subsection"],

Cell["These are equations (1)-(2)", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"EllipticF", "[", 
       RowBox[{
        RowBox[{"ArcSin", "[", 
         SqrtBox[
          FractionBox["1", "c5"]], "]"}], ",", "c5"}], "]"}], ",", 
      RowBox[{
       RowBox[{"1", "/", 
        SqrtBox["c5"]}], " ", 
       RowBox[{"(", 
        RowBox[{"EllipticK", "[", 
         FractionBox["1", "c5"], "]"}], ")"}]}]}], "}"}], "//.", 
    RowBox[{"c5", "\[Rule]", "800"}]}], "//", "N"}], "//", "Chop"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"EllipticE", "[", 
       RowBox[{
        RowBox[{"ArcSin", "[", 
         SqrtBox[
          FractionBox["1", "c5"]], "]"}], ",", "c5"}], "]"}], ",", 
      RowBox[{
       SqrtBox["c5"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"EllipticE", "[", 
          FractionBox["1", "c5"], "]"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            FractionBox["1", "c5"]}], ")"}], " ", 
          RowBox[{"EllipticK", "[", 
           FractionBox["1", "c5"], "]"}]}]}], ")"}]}]}], "}"}], "//.", 
    RowBox[{"c5", "\[Rule]", "800"}]}], "//", "N"}], "//", "Chop"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Real-Imaginary components", "Subsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"EllipticK", "[", "m", "]"}], "/.", 
   RowBox[{"m", "\[Rule]", "3"}]}], "//", "N"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    FractionBox["1", 
     SqrtBox["m"]], 
    RowBox[{"EllipticK", "[", 
     RowBox[{"1", "/", "m"}], "]"}]}], "/.", 
   RowBox[{"m", "\[Rule]", "3"}]}], "//", "N"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", 
      SqrtBox["m"]]}], 
    RowBox[{"EllipticK", "[", 
     RowBox[{"1", "-", 
      RowBox[{"1", "/", "m"}]}], "]"}]}], "/.", 
   RowBox[{"m", "\[Rule]", "3"}]}], "//", "N"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"EllipticE", "[", "m", "]"}], "/.", 
   RowBox[{"m", "\[Rule]", "3"}]}], "//", "N"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    SqrtBox["m"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"EllipticE", "[", 
       RowBox[{"1", "/", "m"}], "]"}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"1", "/", "m"}]}], ")"}], 
       RowBox[{"EllipticK", "[", 
        RowBox[{"1", "/", "m"}], "]"}]}]}], ")"}]}], "/.", 
   RowBox[{"m", "\[Rule]", "3"}]}], "//", "N"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     SqrtBox["m"], 
     RowBox[{"EllipticE", "[", 
      RowBox[{"1", "-", 
       RowBox[{"1", "/", "m"}]}], "]"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", 
       SqrtBox["m"]}], ")"}], 
     RowBox[{"EllipticK", "[", 
      RowBox[{"1", "-", 
       RowBox[{"1", "/", "m"}]}], "]"}]}]}], "/.", 
   RowBox[{"m", "\[Rule]", "3"}]}], "//", "N"}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Appendix A: Reciprocal-modulus transformations", "Subsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"EllipticF", "[", 
     RowBox[{"\[Phi]", ",", "m"}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Phi]", "\[Rule]", "0.5"}], ",", 
      RowBox[{"m", "\[Rule]", "2"}]}], "}"}]}], "//", "N"}], "//", 
  "Chop"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    FractionBox["1", 
     SqrtBox["m"]], 
    RowBox[{"EllipticF", "[", 
     RowBox[{
      RowBox[{"ArcSin", "[", 
       RowBox[{
        SqrtBox["m"], 
        RowBox[{"Sin", "[", "\[Phi]", "]"}]}], "]"}], ",", 
      FractionBox["1", "m"]}], "]"}]}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Phi]", "\[Rule]", "0.5"}], ",", 
     RowBox[{"m", "\[Rule]", "2"}]}], "}"}]}], "//", "N"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"EllipticE", "[", 
     RowBox[{"z", ",", "m"}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"z", "\[Rule]", "0.5"}], ",", 
      RowBox[{"m", "\[Rule]", "2"}]}], "}"}]}], "//", "N"}], "//", 
  "Chop"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     SqrtBox["m"], 
     RowBox[{"EllipticE", "[", 
      RowBox[{
       RowBox[{"ArcSin", "[", 
        RowBox[{
         SqrtBox["m"], 
         RowBox[{"Sin", "[", "z", "]"}]}], "]"}], ",", 
       FractionBox["1", "m"]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["m"]}], "+", 
       FractionBox["1", 
        SqrtBox["m"]]}], ")"}], 
     RowBox[{"EllipticF", "[", 
      RowBox[{
       RowBox[{"ArcSin", "[", 
        RowBox[{
         SqrtBox["m"], 
         RowBox[{"Sin", "[", "z", "]"}]}], "]"}], ",", 
       FractionBox["1", "m"]}], "]"}]}]}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z", "\[Rule]", "0.5"}], ",", 
     RowBox[{"m", "\[Rule]", "2"}]}], "}"}]}], "//", "N"}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Appendix B: Imaginary-modulus transformations", "Subsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"EllipticF", "[", 
    RowBox[{"\[Phi]", ",", 
     RowBox[{"-", "m"}]}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Phi]", "\[Rule]", "0.5"}], ",", 
     RowBox[{"m", "\[Rule]", "2"}]}], "}"}]}], "//", 
  "N"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    FractionBox["1", 
     SqrtBox[
      RowBox[{"1", "+", "m"}]]], 
    RowBox[{"EllipticF", "[", 
     RowBox[{
      RowBox[{"ArcSin", "[", 
       FractionBox[
        RowBox[{
         RowBox[{"Sin", "[", "\[Phi]", "]"}], 
         SqrtBox[
          RowBox[{"1", "+", "m"}]]}], 
        SqrtBox[
         RowBox[{"1", "+", 
          RowBox[{"m", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", "\[Phi]", "]"}], "2"]}]}]]], "]"}], ",", 
      FractionBox["m", 
       RowBox[{"1", "+", "m"}]]}], "]"}]}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Phi]", "\[Rule]", "0.5"}], ",", 
     RowBox[{"m", "\[Rule]", "2"}]}], "}"}]}], "//", 
  "N"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"EllipticK", "[", 
    RowBox[{"-", "m"}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{"m", "\[Rule]", "2"}], "}"}]}], "//", 
  "N"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    FractionBox["1", 
     SqrtBox[
      RowBox[{"1", "+", "m"}]]], 
    RowBox[{"EllipticK", "[", 
     FractionBox["m", 
      RowBox[{"1", "+", "m"}]], "]"}]}], "/.", 
   RowBox[{"{", 
    RowBox[{"m", "\[Rule]", "2"}], "}"}]}], "//", "N"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"EllipticE", "[", 
     RowBox[{"z", ",", 
      RowBox[{"-", "m"}]}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"z", "\[Rule]", "0.5"}], ",", 
      RowBox[{"m", "\[Rule]", "2"}]}], "}"}]}], "//", "N"}], "//", 
  "Chop"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SqrtBox[
       RowBox[{"1", "+", "m"}]], 
      RowBox[{"EllipticE", "[", 
       RowBox[{"t", ",", 
        FractionBox["m", 
         RowBox[{"m", "+", "1"}]]}], "]"}]}], "-", 
     FractionBox[
      RowBox[{"m", " ", 
       RowBox[{"Sin", "[", "t", "]"}], 
       RowBox[{"Cos", "[", "t", "]"}]}], 
      SqrtBox[
       RowBox[{"1", "+", 
        RowBox[{"m", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "t", "]"}], "2"]}]}]]]}], "/.", 
    RowBox[{"t", "\[Rule]", 
     RowBox[{"ArcSin", "[", 
      FractionBox[
       RowBox[{
        RowBox[{"Sin", "[", "z", "]"}], 
        SqrtBox[
         RowBox[{"1", "+", "m"}]]}], 
       SqrtBox[
        RowBox[{"1", "+", 
         RowBox[{"m", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", "z", "]"}], "2"]}]}]]], "]"}]}]}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z", "\[Rule]", "0.5"}], ",", 
     RowBox[{"m", "\[Rule]", "2"}]}], "}"}]}], "//", "N"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"param", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", 
      RowBox[{"-", "0.5"}]}], ",", 
     RowBox[{"z", "\[Rule]", 
      RowBox[{"\[Pi]", "/", "2"}]}], ",", 
     RowBox[{"m", "\[Rule]", "2"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"EllipticPi", "[", 
    RowBox[{"a", ",", "z", ",", 
     RowBox[{"-", "m"}]}], "]"}], "/.", "param"}], "//", 
  "N"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"m", " ", 
       RowBox[{"EllipticF", "[", 
        RowBox[{"t", ",", 
         FractionBox["m", 
          RowBox[{"1", "+", "m"}]]}], "]"}]}], 
      RowBox[{
       SqrtBox[
        RowBox[{"1", "+", "m"}]], " ", 
       RowBox[{"(", 
        RowBox[{"a", "+", "m"}], ")"}]}]], "+", 
     FractionBox[
      RowBox[{"a", " ", 
       RowBox[{"EllipticPi", "[", 
        RowBox[{
         FractionBox[
          RowBox[{"a", "+", "m"}], 
          RowBox[{"1", "+", "m"}]], ",", "t", ",", 
         FractionBox["m", 
          RowBox[{"1", "+", "m"}]]}], "]"}]}], 
      RowBox[{
       SqrtBox[
        RowBox[{"1", "+", "m"}]], " ", 
       RowBox[{"(", 
        RowBox[{"a", "+", "m"}], ")"}]}]]}], "/.", 
    RowBox[{"t", "\[Rule]", 
     RowBox[{"ArcSin", "[", 
      FractionBox[
       RowBox[{
        RowBox[{"Sin", "[", "z", "]"}], 
        SqrtBox[
         RowBox[{"1", "+", "m"}]]}], 
       SqrtBox[
        RowBox[{"1", "+", 
         RowBox[{"m", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", "z", "]"}], "2"]}]}]]], "]"}]}]}], "/.", 
   "param"}], "//", "N"}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Singularities", "Subsection"],

Cell["Singularity for coincident faces:", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"s3", "[", 
   RowBox[{"r1_", ",", "r2_", ",", "zt_", ",", "ztt_"}], "]"}], ":=", " ", 
  "\[IndentingNewLine]", 
  RowBox[{"s4", "[", 
   RowBox[{
    RowBox[{"zt", "-", "ztt"}], ",", 
    RowBox[{"r1", "-", "r2"}], ",", 
    RowBox[{"r1", "+", "r2"}], ",", 
    SqrtBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"r1", "-", "r2"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"zt", "-", "ztt"}], ")"}], "2"]}]], ",", 
    SqrtBox[
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"r1", "+", "r2"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"zt", "-", "ztt"}], ")"}], "2"]}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"r1", "-", "r2"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"zt", "-", "ztt"}], ")"}], "2"]}]]]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"s4", "[", 
   RowBox[{"c1_", ",", "c2_", ",", "c3_", ",", "c4_", ",", "c5_"}], "]"}], ":=",
   " ", 
  RowBox[{"c1", " ", "c4", 
   RowBox[{"(", 
    RowBox[{"2", 
     FractionBox[
      SuperscriptBox["c3", "2"], 
      SuperscriptBox["c4", "2"]], 
     RowBox[{"EllipticPi", "[", 
      RowBox[{
       RowBox[{"1", "-", 
        FractionBox[
         SuperscriptBox["c3", "2"], 
         SuperscriptBox["c2", "2"]]}], ",", 
       RowBox[{"1", "-", 
        SuperscriptBox["c5", "2"]}]}], "]"}]}], 
    ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"z1", "\[Equal]", "z2"}], "}"}], ",", " ", 
   RowBox[{
    RowBox[{"s3", "[", 
     RowBox[{"r1", ",", "r2", ",", "z1", ",", "z2"}], "]"}], "//", 
    "FullSimplify"}]}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EllipticE", "[", 
   RowBox[{"-", "5"}], "]"}], "//", "N"}]], "Input"],

Cell["Singularity term for equal radii:", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"s3", "[", 
   RowBox[{"r1_", ",", "r2_", ",", "zt_", ",", "ztt_"}], "]"}], ":=", " ", 
  "\[IndentingNewLine]", 
  RowBox[{"s4", "[", 
   RowBox[{
    RowBox[{"zt", "-", "ztt"}], ",", 
    RowBox[{"r1", "-", "r2"}], ",", 
    RowBox[{"r1", "+", "r2"}], ",", 
    SqrtBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"r1", "-", "r2"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"zt", "-", "ztt"}], ")"}], "2"]}]], ",", 
    SqrtBox[
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"r1", "+", "r2"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"zt", "-", "ztt"}], ")"}], "2"]}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"r1", "-", "r2"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"zt", "-", "ztt"}], ")"}], "2"]}]]]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"s4", "[", 
   RowBox[{"c1_", ",", "c2_", ",", "c3_", ",", "c4_", ",", "c5_"}], "]"}], ":=",
   " ", 
  RowBox[{"c1", " ", "c4", 
   RowBox[{"(", 
    RowBox[{"2", 
     FractionBox[
      SuperscriptBox["c3", "2"], 
      SuperscriptBox["c4", "2"]], 
     RowBox[{"EllipticPi", "[", 
      RowBox[{
       RowBox[{"1", "-", 
        FractionBox[
         SuperscriptBox["c3", "2"], 
         SuperscriptBox["c2", "2"]]}], ",", 
       RowBox[{"1", "-", 
        SuperscriptBox["c5", "2"]}]}], "]"}]}], 
    ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"r1", "\[Equal]", "r2"}], "}"}], ",", 
   RowBox[{
    RowBox[{"s3", "[", 
     RowBox[{"r1", ",", "r2", ",", "z1", ",", "z2"}], "]"}], "//", 
    "FullSimplify"}]}], "]"}]}], "Input"],

Cell["\<\
And now the other three terms for equal radii and coincident faces:\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"s3", "[", 
   RowBox[{"r1_", ",", "r2_", ",", "zt_", ",", "ztt_"}], "]"}], ":=", " ", 
  "\[IndentingNewLine]", 
  RowBox[{"s4", "[", 
   RowBox[{
    RowBox[{"zt", "-", "ztt"}], ",", 
    RowBox[{"r1", "-", "r2"}], ",", 
    RowBox[{"r1", "+", "r2"}], ",", 
    SqrtBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"r1", "-", "r2"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"zt", "-", "ztt"}], ")"}], "2"]}]], ",", 
    SqrtBox[
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"r1", "+", "r2"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"zt", "-", "ztt"}], ")"}], "2"]}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"r1", "-", "r2"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"zt", "-", "ztt"}], ")"}], "2"]}]]]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"s4", "[", 
   RowBox[{"c1_", ",", "c2_", ",", "c3_", ",", "c4_", ",", "c5_"}], "]"}], ":=",
   " ", 
  RowBox[{"c1", " ", "c4", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "c5", " ", 
      RowBox[{"EllipticE", "[", 
       RowBox[{"1", "-", 
        FractionBox["1", 
         SuperscriptBox["c5", "2"]]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", "c5"], "+", "c5"}], " ", ")"}], 
      RowBox[{"EllipticK", "[", 
       RowBox[{"1", "-", 
        FractionBox["1", 
         SuperscriptBox["c5", "2"]]}], "]"}]}], "\[IndentingNewLine]", "+", 
     RowBox[{
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         SuperscriptBox["c2", "2"], "+", 
         SuperscriptBox["c3", "2"]}], 
        SuperscriptBox["c4", "2"]], ")"}], " ", 
      RowBox[{"EllipticK", "[", 
       RowBox[{"1", "-", 
        SuperscriptBox["c5", "2"]}], "]"}]}]}], 
    ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"z1", "\[Equal]", "z2"}], "}"}], ",", 
   RowBox[{
    RowBox[{"s3", "[", 
     RowBox[{"r1", ",", "r2", ",", "z1", ",", "z2"}], "]"}], "//", 
    "FullSimplify"}]}], "]"}]}], "Input"]
}, Closed]]
}, Open  ]]
},
WindowSize->{916, 689},
WindowMargins->{{46, Automatic}, {Automatic, 55}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
ShowSelection->True,
FrontEndVersion->"6.0 for Mac OS X x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 49, 0, 67, "Section"],
Cell[642, 25, 338, 8, 41, "Text"],
Cell[CellGroupData[{
Cell[1005, 37, 33, 0, 34, "Subsection"],
Cell[1041, 39, 244, 4, 41, "Text"],
Cell[CellGroupData[{
Cell[1310, 47, 57, 0, 25, "Subsubsection"],
Cell[1370, 49, 9868, 287, 566, "Input"],
Cell[11241, 338, 881, 20, 73, "Input"],
Cell[12125, 360, 1772, 47, 88, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[13934, 412, 42, 0, 19, "Subsubsection"],
Cell[13979, 414, 440, 9, 56, "Text"],
Cell[14422, 425, 8390, 241, 777, "Input"],
Cell[22815, 668, 1773, 47, 88, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[24625, 720, 64, 0, 19, "Subsubsection"],
Cell[24692, 722, 5220, 151, 406, "Input"],
Cell[29915, 875, 1769, 47, 88, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[31721, 927, 43, 0, 19, "Subsubsection"],
Cell[31767, 929, 178, 5, 26, "Text"],
Cell[31948, 936, 3792, 110, 279, "Input"],
Cell[35743, 1048, 1770, 47, 88, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[37550, 1100, 42, 0, 19, "Subsubsection"],
Cell[37595, 1102, 209, 4, 73, "Input"],
Cell[37807, 1108, 175, 3, 58, "Input"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[38043, 1118, 26, 0, 67, "Section"],
Cell[38072, 1120, 2828, 79, 133, "Input"],
Cell[40903, 1201, 769, 20, 43, "Input"],
Cell[41675, 1223, 48, 0, 26, "Text"],
Cell[41726, 1225, 831, 24, 103, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[42594, 1254, 34, 0, 37, "Section"],
Cell[CellGroupData[{
Cell[42653, 1258, 57, 0, 34, "Subsection"],
Cell[42713, 1260, 43, 0, 26, "Text"],
Cell[42759, 1262, 518, 17, 53, "Input"],
Cell[43280, 1281, 720, 23, 71, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[44037, 1309, 47, 0, 26, "Subsection"],
Cell[44087, 1311, 644, 22, 108, "Input"],
Cell[44734, 1335, 1021, 35, 74, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[45792, 1375, 68, 0, 26, "Subsection"],
Cell[45863, 1377, 760, 26, 67, "Input"],
Cell[46626, 1405, 1117, 40, 87, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[47780, 1450, 67, 0, 26, "Subsection"],
Cell[47850, 1452, 1515, 54, 139, "Input"],
Cell[49368, 1508, 1356, 47, 81, "Input"],
Cell[50727, 1557, 1659, 57, 97, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[52423, 1619, 35, 0, 26, "Subsection"],
Cell[52461, 1621, 49, 0, 26, "Text"],
Cell[52513, 1623, 1836, 61, 146, "Input"],
Cell[54352, 1686, 105, 3, 27, "Input"],
Cell[54460, 1691, 49, 0, 26, "Text"],
Cell[54512, 1693, 1831, 61, 146, "Input"],
Cell[56346, 1756, 91, 2, 26, "Text"],
Cell[56440, 1760, 2262, 74, 186, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
